abacusai.pipeline_step — AbacusAI documentation

# `abacusai.pipeline_step`

## Module Contents

### Classes

`PipelineStep` | A step in a pipeline.

class abacusai.pipeline_step.PipelineStep(client, pipelineStepId=None, pipelineId=None, stepName=None, pipelineName=None, createdAt=None, updatedAt=None, pythonFunctionId=None, stepDependencies=None, cpuSize=None, memory=None, pythonFunction={}, codeSource={})

  Bases: `abacusai.return_class.AbstractApiClass`

  A step in a pipeline.

  Parameters:

    - client (ApiClient) – An authenticated API Client instance

    - pipelineStepId (str) – The reference to this step.

    - pipelineId (str) – The reference to the pipeline this step belongs to.

    - stepName (str) – The name of the step.

    - pipelineName (str) – The name of the pipeline this step is a part of.

    - createdAt (str) – The date and time which this step was created.

    - updatedAt (str) – The date and time when this step was last updated.

    - pythonFunctionId (str) – The python function_id.

    - stepDependencies (list[str]) – List of steps this step depends on.

    - cpuSize (str) – CPU size specified for the step function.

    - memory (int) – Memory in GB specified for the step function.

    - pythonFunction (PythonFunction) – Information about the python function for the step.

    - codeSource (CodeSource) – Information about the source code of the step function.

  __repr__()

    Return repr(self).

  to_dict()

    Get a dict representation of the parameters in this class

    Returns:

      The dict value representation of the class parameters

    Return type:

      dict

  delete()

    Deletes a step from a pipeline.

    Parameters:

      pipeline_step_id (str) – The ID of the pipeline step.

  update(function_name=None, source_code=None, step_input_mappings=None, output_variable_mappings=None, step_dependencies=None, package_requirements=None, cpu_size=None, memory=None)

    Creates a step in a given pipeline.

    Parameters:

      - function_name (str) – The name of the Python function.

      - source_code (str) – Contents of a valid Python source code file. The source code should contain the transform feature group functions. A list of allowed imports and system libraries for each language is specified in the user functions documentation section.

      - step_input_mappings (list) – List of Python function arguments.

      - output_variable_mappings (list) – List of Python function ouputs.

      - step_dependencies (list) – List of step names this step depends on.

      - package_requirements (list) – List of package requirement strings. For example: [‘numpy==1.2.3’, ‘pandas>=1.4.0’].

      - cpu_size (str) – Size of the CPU for the step function.

      - memory (int) – Memory (in GB) for the step function.

    Returns:

      Object describing the pipeline.

    Return type:

      PipelineStep

  rename(step_name)

    Renames a step in a given pipeline.

    Parameters:

      step_name (str) – The name of the step.

    Returns:

      Object describing the pipeline.

    Return type:

      PipelineStep

  refresh()

    Calls describe and refreshes the current object’s fields

    Returns:

      The current object

    Return type:

      PipelineStep

  describe()

    Deletes a step from a pipeline.

    Parameters:

      pipeline_step_id (str) – The ID of the pipeline step.

    Returns:

      An object describing the pipeline step.

    Return type:

      PipelineStep